[
https://issues.apache.org/jira/browse/ARROW-7614?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=17020171#comment-17020171
]
Joris Van den Bossche commented on ARROW-7614:
----------------------------------------------
I think it is due to the test set-up. Also when I remove the specifying of the
{{data_page_size}} option leaving the test for the rest intact, I get similarly
slow test duration as with keeping it.
So I assume we can just limit the data in the test a bit.
> [Python] Slow performance in test_parquet.py::test_set_data_page_size
> ---------------------------------------------------------------------
>
> Key: ARROW-7614
> URL: https://issues.apache.org/jira/browse/ARROW-7614
> Project: Apache Arrow
> Issue Type: Bug
> Components: Python
> Reporter: Wes McKinney
> Priority: Major
> Fix For: 1.0.0
>
>
> Slowest test durations:
> {code}
> 3.73s call pyarrow/tests/test_parquet.py::test_set_data_page_size
> 0.05s call
> pyarrow/tests/test_parquet.py::test_nested_list_nonnullable_roundtrip_bug
> 0.03s call pyarrow/tests/test_parquet.py::test_compression_level
> 0.03s call
> pyarrow/tests/test_parquet.py::test_dictionary_array_automatically_read
> 0.02s call
> pyarrow/tests/test_parquet.py::test_statistics_convert_logical_types
> 0.02s call pyarrow/tests/test_parquet.py::test_large_list_records
> 0.01s call
> pyarrow/tests/test_parquet.py::test_write_nested_zero_length_array_chunk_failure
> 0.01s call
> pyarrow/tests/test_parquet.py::test_parquet_write_disable_statistics
> 0.01s call
> pyarrow/tests/test_parquet.py::test_single_pylist_column_roundtrip[int]
> 0.01s call pyarrow/tests/test_parquet.py::test_special_chars_filename
> {code}
> This suggests to me there is something wrong with the feature (possibly doing
> unnecessary work)
--
This message was sent by Atlassian Jira
(v8.3.4#803005)